#
# spec file for package avfs
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           avfs
Version:        1.0.5
Release:        14.48
Summary:        AVFS - an archive look-inside filesystem
License:        GPL-2.0+ AND LGPL-2.1+
Group:          Productivity/Archiving/Compression
URL:            http://avf.sourceforge.net/
Source0:        https://downloads.sf.net/avf/%{name}-%{version}.tar.bz2
Source1:        https://downloads.sf.net/avf/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
BuildRequires:  emacs-nox
BuildRequires:  help2man
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(e2p)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(ext2fs)
BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(neon)
BuildRequires:  pkgconfig(openssl)

%description
AVFS is a filesystem which enables all programs to look inside archived or
compressed files, or access remote files without recompiling the programs
or changing the kernel.

%package devel
Summary:        Development files for AVFS, an archive look-inside filesystem
Group:          Development/Libraries/C and C++
Requires:       libavfs0 = %{version}

%description devel
This package includes the development file for the package avfs.
AVFS is a filesystem which enables all programs to look inside archived or
compressed files, or access remote files without recompiling the programs
or changing the kernel.

%package -n libavfs0
Summary:        Shared library for AVFS, an archive look-inside filesystem
Group:          System/Libraries

%description -n libavfs0
This package includes the runtime shared library for the package avfs.
AVFS is a system, which enables all programs to look inside archived or
compressed files, or access remote files without recompiling the programs
or changing the kernel.

%prep
%setup -q

%build
%configure \
  --disable-avfscoda \
  --enable-library \
  --enable-fuse \
  --disable-static \
  --enable-shared \
  --with-system-zlib \
  --with-system-bzlib \
  --with-gnu-ld \
  --enable-libxml \
  --with-neon \
  --with-ssl \
  --with-xz
make %{?_smp_mflags}

%install
%make_install

pushd %{buildroot}%{_libdir}/%{name}/extfs/
    mv uzip ext-uzip
popd
mkdir -p %{buildroot}/%{_mandir}/man1/
pushd %{buildroot}/%{_mandir}/man1/
    LD_LIBRARY_PATH=%{buildroot}/%{_libdir} \
    PATH=%{buildroot}/%{_bindir}:$PATH \
    help2man -s 1 -N --no-discard-stderr avfsd | \
    sed 's/^FUSE \\- .*/AVFS - A Virtual File System/' > \
    avfsd.1
popd

rm -vf %{buildroot}/%{_libdir}/libavfs.la

%post -n libavfs0 -p /sbin/ldconfig
%postun -n libavfs0 -p /sbin/ldconfig

%files
%doc ChangeLog README NEWS TODO
%license COPYING
%doc doc/api-overview
%doc doc/background
%doc doc/FORMAT
%doc doc/README.avfs-fuse
%{_bindir}/avfsd
%{_bindir}/davpass
%{_bindir}/ftppass
%{_bindir}/mountavfs
%{_bindir}/umountavfs
%dir %{_libdir}/avfs
%dir %{_libdir}/avfs/extfs
%{_libdir}/avfs/extfs/*
%{_mandir}/man1/avfsd.1%{ext_man}

%files devel
%{_bindir}/avfs-config
%{_includedir}/avfs.h
%{_includedir}/virtual.h
%{_libdir}/libavfs.so

%files -n libavfs0
%{_libdir}/libavfs.so.0
%{_libdir}/libavfs.so.0.0.2

%changelog
* Mon Feb 19 2018 aloisio@gmx.com
- Update to version 1.0.5
  * limit the file cache to 50 elements and age of 10 minutes to
    avoid endless grow of internal cache
  * allow reproducable builds
  * fixed crash in parsing ls output for modules which need to
    handle ls-like output
  * fix urar module when external rar/unrar tool crashed
- Spec cleanup
* Thu Dec 22 2016 mpluskal@suse.com
- Update to version 1.0.4:
  * fixed zip module to correctly read archives with a lot of
    files or very large files
- Use pkgconfig() style requires
* Wed Nov 11 2015 p.drouand@gmail.com
- Update to version 1.0.3
  * fixed zlib assert triggered for some Huffman encodings
  * added rar v5 in extfs urar (which is also renamed to uextrar to avoid
    collision with internal rar module)
  * some configure script improvements have been done for fuse and liblzma
    dependencies
* Sun May 17 2015 jengelh@inai.de
- Improve summary and description. -devel subpackage should require
  same-version shared library. Drop --with-pic, because it is
  implicit for shared libraries (and we do not build static).
  Use short Sourceforge download URLs.
* Tue May 12 2015 mpluskal@suse.com
- Update licensing information
* Fri May  8 2015 mpluskal@suse.com
- Update to 1.0.2
- Add gpg signature
- Clenup spec file with spec-cleaner
- Drop avfs-1.0.0.dif as it fails to apply to current release
* Tue May  8 2012 werner@suse.de
- First initial package for mounting tar and other bells and whistles
